package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`/@`!````\"5``#0````DLP```````#0`(``,
M`"@`'``;``8````T````-`!``#0`0`"``0``@`$```0````$`````P```+0!
M``"T`4``M`%``!H````:````!`````$````!````````````0````$``2!(`
M`$@2```$`````!````$`````(````"!````@0`"M,P``K3,```4`````$```
M`0````!@````8$```&!``+A%``"X10``!``````0```!````>*X``'B^0`!X
MOD``>`,``+P3```&`````!````(```"`K@``@+Y``("^0``0`0``$`$```8`
M```$````!````-`!``#0`4``T`%``'@```!X````!`````0```!3Y71D]`$`
M`/0!0`#T`4``-````#0````$````!````%#E=&1`GP``0)]``$"?0`#4````
MU`````0````$````4>5T9```````````````````````````!@```!````!2
MY71D>*X``'B^0`!XOD``B`$``(@!```$`````0```"]L:6)X,S(O;&0M;&EN
M=7@M>#,R+G-O+C(````$````%`````,```!'3E4`>0Q?+7G[7R)S$QPU00$C
MF><)DZT$````)`````4```!'3E4``H``P`0````!`````0`!P`0````)````
M`@`!P`0````!````!````!`````!````1TY5```````#````!``````````1
M````20````0````'`````)$0`)MDA$@(CA`ABH0$R`````!)````3````$\`
M``!0````5@```%<```!8`````````%H`````````6P```%P```!=````7@``
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,S8MOM#3J7"W^IG)OA
MIP(*H^#[20````````````````````#<`0`````````````2````PP(`````
M````````$@```!L!`````````````!(```#I`0`````````````2````/P(`
M````````````$@```)8``````````````!(```"B`0`````````````2````
M^`(`````````````$@```"`!`````````````!(```#Z`0`````````````2
M````,0$`````````````$@```-("`````````````!(````!````````````
M```@````O0(`````````````$@```!P#`````````````!(````1`@``````
M```````2````RP(`````````````$@````,"`````````````!(```!B`0``
M```````````2````MP``````````````$@```%(!`````````````!(```#G
M`@`````````````2````:@(`````````````$@```$0!`````````````!(`
M``#+`0`````````````2````$```````````````(````,`!````````````
M`!(````L```````````````@````&0(`````````````$@```(\"````````
M`````!(```!&```````````````2````8P``````````````%@```)(!````
M`````````!(````"`P`````````````1````=@``````````````$@```.<#
M`````````````!(```#S```````````````2````AP``````````````$@``
M`-D"`````````````!(```!:`@`````````````2````X`(`````````````
M$@```$8"`````````````!(````R`@`````````````2````UP``````````
M````$@```+8"`````````````!(```!4`@`````````````2````A`$`````
M````````$@```/,!`````````````!(```"O`@`````````````2````J`(`
M````````````$0```'8!`````````````!(````@`@`````````````2````
M!`$`````````````$@`````#`````````````!$````E`0`````````````2
M````)P(`````````````$@```'("`````````````!(```".`@``````````
M```2````+0(`````````````$@````H#`````````````!(```"``@``````
M```````2````H@``````````````$@````H"`````````````!(```"M`0``
M```````````2````Y@``````````````$0```+D!`````````````!(```#A
M`0`````````````2````:P$`````````````$@```%0``````````````!(`
M``"6`@`````````````2````80(`````````````$@```,4`````````````
M`!(```#P`P``,%-``%X````2``X`,00``!!%0`"J"@``$@`.`*,"``#P(T``
M_P$``!(`#@!Q`P``X#M```4````2``X`CP,``,!/0`!I`P``$@`.`%<$``#P
M.T``XP$``!(`#@`@!```\,%````````0`!D`@@,``.`]0``D````$@`.`*4#
M``"`0T``:@```!(`#@#\`P```&!```0````1`!``&`0``,`Z0``O````$@`.
M`"P$```TTD```````!``&0!%!```$$1``/4````2``X`"P0``.#!0```````
M$``8`,D#```0/D``VP```!(`#@`^!```\,%````````0`!@`9`0``.S!0``$
M````$0`8`!$$``#P)4``*````!(`#@`-!```X,%````````@`!@`U0,``/!#
M0``>````$@`.`+,#```P.T``J@```!(`#@!N!```\#Y``(X$```2``X``%]?
M9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!097)L7V-R;V%K7VUE
M;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T
M`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`=6YL:6YK`&UE;6UO=F4`<W1R=&]K
M`'-T<FQE;@!R;61I<@!R96%D`%]?;65M8W!Y7V-H:P!S=')S='(`7U]S=')N
M8W!Y7V-H:P!M:V1I<@!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN
M=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I
M;@!S=&1E<G(`;65M8VAR`'-T<F-H<@!C;&]S90!O<&5N9&ER`&=E='5I9`!A
M8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?=&QS7V=E=%]A9&1R`&QI
M8G!E<FPN<V\N-2XS-BXP`&QI8FTN<V\N-@!L:6)C+G-O+C8`;&0M;&EN=7@M
M>#,R+G-O+C(`;&EB8W)Y<'0N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B
M87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D
M871A7W-T87)T`'AS7VEN:70`7U]B<W-?<W1A<G0`7V5N9`!P87)?;6MT;7!D
M:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`$=,24)#7S(N,38`1TQ)0D-?,BXS-`!'3$E"
M0U\R+C,S`"]U<W(O;&EB>#,R+W!E<FPU+S4N,S8N,"]X.#9?-C0M<&QD+6QI
M;G5X+6=N=7@S,BUT:')E860M;75L=&DO0T]210`````"``(``0`"``(``0`!
M``(``@`"``$``@`!``(``P`"``(``@`!``$``0`"``(``0`"``$``0`!``(`
M!``!``$``0`"``$``@`!``$``@`"``(``@`"``$``@`"``$``@`"``(``0`"
M``$``@`!``(``@`$``(``@`"``$``@`!``$``@`"``$``0`%``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`!
M`%$#```0````(````):1E@8```,`>P0````````!``,`1P,``!``````````
MM)&6!@``!0"&!```$````+.1E@8```0`D00``!````"6D98&```"`'L$````
M````D+]```8+````````F+]```8-````````H+]```8:````````J+]```8<
M````````L+]``!(@````````N+]```8A````````P+]```8B````````R+]`
M``8C````````T+]```8R````````V+]```9!````````X+]```9&````````
M`,!```<!````````",!```<"````````$,!```<#````````&,!```<$````
M````(,!```<%````````*,!```<&````````,,!```<'````````.,!```<(
M````````0,!```<)````````2,!```<*````````4,!```<,````````6,!`
M``<.````````8,!```</````````:,!```<0````````<,!```<1````````
M>,!```<2````````@,!```<3````````B,!```<4````````D,!```<5````
M````F,!```<6````````H,!```<7````````J,!```<8````````L,!```<9
M````````N,!```<;````````P,!```<=````````R,!```<>````````T,!`
M``<?````````V,!```<D````````X,!```<E````````Z,!```<F````````
M\,!```<G````````^,!```<H`````````,%```<I````````",%```<J````
M````$,%```<K````````&,%```<L````````(,%```<M````````*,%```<N
M````````,,%```<O````````.,%```<P````````0,%```<Q````````2,%`
M``<S````````4,%```<T````````6,%```<U````````8,%```<W````````
M:,%```<X````````<,%```<Y````````>,%```<Z````````@,%```<[````
M````B,%```<\````````D,%```<]````````F,%```<^````````H,%```<_
M````````J,%```=`````````L,%```="````````N,%```=#````````P,%`
M``=$````````R,%```=%````````T,%```='````````V,%```=(````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!8F?``!(A<!T`O_02(/$",,``````/\URI\``/\ES)\`
M``\?0`#_)<J?``!H`````.G@_____R7"GP``:`$```#IT/____\ENI\``&@"
M````Z<#_____);*?``!H`P```.FP_____R6JGP``:`0```#IH/____\EHI\`
M`&@%````Z9#_____)9J?``!H!@```.F`_____R62GP``:`<```#I</____\E
MBI\``&@(````Z6#_____)8*?``!H"0```.E0_____R5ZGP``:`H```#I0/__
M__\E<I\``&@+````Z3#_____)6J?``!H#````.D@_____R5BGP``:`T```#I
M$/____\E6I\``&@.````Z0#_____)5*?``!H#P```.GP_O___R5*GP``:!``
M``#IX/[___\E0I\``&@1````Z=#^____)3J?``!H$@```.G`_O___R4RGP``
M:!,```#IL/[___\E*I\``&@4````Z:#^____)2*?``!H%0```.F0_O___R4:
MGP``:!8```#I@/[___\E$I\``&@7````Z7#^____)0J?``!H&````.E@_O__
M_R4"GP``:!D```#I4/[___\E^IX``&@:````Z4#^____)?*>``!H&P```.DP
M_O___R7JG@``:!P```#I(/[___\EXIX``&@=````Z1#^____)=J>``!H'@``
M`.D`_O___R72G@``:!\```#I\/W___\ERIX``&@@````Z>#]____)<*>``!H
M(0```.G0_?___R6ZG@``:"(```#IP/W___\ELIX``&@C````Z;#]____):J>
M``!H)````.F@_?___R6BG@``:"4```#ID/W___\EFIX``&@F````Z8#]____
M)9*>``!H)P```.EP_?___R6*G@``:"@```#I8/W___\E@IX``&@I````Z5#]
M____)7J>``!H*@```.E`_?___R5RG@``:"L```#I,/W___\E:IX``&@L````
MZ2#]____)6*>``!H+0```.D0_?___R5:G@``:"X```#I`/W___\E4IX``&@O
M````Z?#\____)4J>``!H,````.G@_/___R5"G@``:#$```#IT/S___\E.IX`
M`&@R````Z<#\____)3*>``!H,P```.FP_/___R4JG@``:#0```#IH/S___\E
M(IX``&@U````Z9#\____)1J>``!H-@```.F`_/___R42G@``:#<```#I</S_
M__\E"IX``&@X````Z6#\____)0*>``!H.0```.E0_/___R7ZG0``:#H```#I
M0/S___\E\IT``&@[````Z3#\__]!5%6#["B)?"0,C7PD#(ET)`B-="0(B50D
M!(U4)`1DBP0E&````(E$)!PQP.B?____BS5IFP``BSV;FP``2(GRZ%LO``"+
M!9V;``!G@#@`#X09`0``9(L$)0````!(`P5<FP``9XL`9X"(!@,```.+1"0,
MC7@%@?____\_#X=I`0``P><"Z`;___]$BTPD"(M4)`S'!9NM```$````2(G!
MB06.K0``08G`O@$```!G08L!9XD!C04=/0``9XE!!,?`[,%``&>+`&>)00B-
M!0D]``!GB4$,@_H!?A</'T0``&=!BSRQ9T&)?+`,@\8!.?)U[F=!QT20#```
M``"+/3ZM``"#P@-%,<"--?(5``#HC?O__T&)Q(7`#X2&````BST<K0``C6PD
M&.BC_?__,<!(B>Z-/7L[``#H@P\``$B%P'1UBSWXK```Z!/[___HCOS__XM$
M)!QD*P0E&`````^%E@```(/$*$2)X%U!7,/H/?S__XD%QZP``$B)QX7`='#H
MB_S__V2+!"4`````2`,%+)H``&>+`&?&@+,&````Z;'^__^+/9:L``#HD?O_
M_T&)Q.EG____BSU_K```A?]T"NAZ+0``Z7?___^-/9<Z``!(B>[HYPX``(D%
M7:P``(G'A<`/A%G____KUN@`_?__OP$```#H1OK__^BA^___D/,/'OHQ[4&)
MT8LT)(/$!(GB@^3P4%1%,<`QR<?'\"-``/\5R9D``/0/'X0``````/,/'OK#
M9BX/'X0``````)"-/;J;``"-!;2;```Y^'00BP5:F0``A<!T!HG`_^!FD,-F
M9BX/'X0```````\?0`"-/8J;``"--82;```I_HGPP>X?P?@"`<;1_G04BP4F
MF0``A<!T"HG`_^!F#Q]$``##9F8N#Q^$```````/'T``\P\>^H`]59L```!U
M$U6)Y>A[____Q@5$FP```5W#9I##9F8N#Q^$```````/'T``\P\>^NN*9BX/
M'X0``````$%52(G^05154X'L6`$``&2+!"48````B80D3`$``#'`B>)F#Q]$
M``!GBTR&'`_)9XD,@H/``8/X$'7MC8PD``$``&8/'T0``&>+0C1G,T(@@\($
M9S-"!&<S0OS1P&>)0CPYRG7C9XLN9XM>$(L$)&=$BU8(B>IG1(M.#&=$BUX$
M08GLP<(%18G0BTPD!$'!S`*-A`.9>8):1(ML)`P!T$2)TD&-C`F9>8):1#'*
M1"':1#'*`=!$B=K!R@)!,=")UT$AZ$0QYT4QT"''00'(B<$QU\'(`L'!!4*-
ME"J9>8):1(ML)!!!`<B+3"0(08V,"IEY@EH!ST2)P<'!!0'/1(GA,<%$(<%!
MP<@"1#'A1XVD+)EY@EI$BVPD%`'1B?K!P@4!T8G"1#'"(?HQPD*-A"B9>8):
M1(ML)!A$`>)!B<Q!P<0%P<\"1`'B18G$03'\02',P<D"13'$1XV$*)EY@EI$
MBVPD'$0!X$&)U$'!Q`5$`>!!B?Q!,<Q!(=3!R@)!,?Q"C;POF7F"6D2+;"0@
M10'@08G$0<'$!44!X$&)S$$QU$$AQ,'(`D$QS$*-C"F9>8):1(ML)"1$`>=%
MB<1!P<0%1`'G08G403'$12'$0<'(`D$QU$*-E"J9>8):1(ML)"A$`>%!B?Q!
MP<0%1`'A08G$13'$02'\P<\"03'$0HV$*)EY@EI$BVPD+$0!XD&)S$'!Q`5$
M`>)%B<1!,?Q!(<S!R0)%,<1'C80HF7F"6D2+;"0P1`'@08G40<'$!40!X$&)
M_$$QS$$AU,'*`D$Q_$*-O"^9>8):1(ML)#1%`>!!B<1!P<0%10'@08G,03'4
M02'$P<@"03',0HV,*9EY@EI$BVPD.$0!YT6)Q$'!Q`5$`>=!B=1!,<1%(<1!
M,=1"C90JF7F"6D2+;"0\1`'A08G\0<'$!40!X4'!R`)!B<1%,<1!(?S!SP)!
M,<1"C80HF7F"6D2+;"1`1`'B08G,0<'$!40!XD6)Q$$Q_$$AS,')`D4QQ$>-
MA"B9>8):1(ML)$1$`>!!B=1!P<0%1`'@08G\03',02'4P<H"03'\0HV\+YEY
M@EI$BVPD2$4!Q$&)P$'!P`5%`<1!B<A!,=!!(<#!R`)!,<A"C8PIF7F"6D2+
M;"1,00'X1(GGP<<%00'XB=<QQT0AYS'70<',`D*-E"J9>8):`<]$B<'!P04!
MSXG!1#'A1"'!,<$!RHGYP<$%`<I$B<%$BT0D4,')`D:-A`"AZ]EN1(G@,<@Q
M^,'/`D$!P(G008G]P<`%00'`BT0D5$&-O`2AZ]ENB<A$,>@QT`''1(G`P<`%
M`<>)T(M4)%C!R`*-C!&AZ]EN1(GJ08G$,<)$,<)!P<@"`=&)^D4QQ,'"!4$Q
M_`'1BU0D7$&-E!6AZ]EN1`'B08G,P<\"0<'$!40!XD2+9"1@0HV$(*'KV6Y%
MB<1!,?Q!,<S!R0)$`>!!B=1!P<0%1`'@1(MD)&1'C80@H>O9;D&)_$$QS$$Q
MU,'*`D4!X$&)Q$'!Q`5%`>!$BV0D:$*-O">AZ]EN08G,03'403'$P<@"1`'G
M18G$0<'$!40!YT2+9"1L0HV,(:'KV6Y!B=1!,<1%,<1!P<@"1`'A08G\0<'$
M!40!X42+9"1P0HV4(J'KV6Y!B<1%,<1!,?Q$`>)!B<Q!P<0%1`'B1(MD)'3!
MSP)"C80@H>O9;D6)Q$$Q_$$QS,')`D0!X$&)U$'!Q`5$`>!$BV0D>$>-A""A
MZ]EN08G\03',03'4P<H"10'@08G$0<'$!44!X$2+9"1\0HV\)Z'KV6Y!B<Q!
M,=1!,<3!R`)$`>=%B<1!P<0%1`'G1(ND)(````!"C8PAH>O9;D&)U$$QQ$4Q
MQ$'!R`)$`>%!B?Q!P<0%1`'A1(ND)(0```!"C90BH>O9;D&)Q$4QQ$$Q_,'/
M`D0!XD&)S$'!Q`5$`>)$BZ0DB````$*-A""AZ]EN18G$03'\03',P<D"1`'@
M08G40<'$!40!X$2+I"2,````1XVD(*'KV6Y!B?A!,<A!,=#!R@)%`<1!B<!!
MP<`%10'$1(N$))````!&C80'H>O9;HG/,=<QQ\'(`D$!^$2)Y\''!4$!^(N\
M))0```"-O#FAZ]ENB=$QP40QX4'!S`(!ST2)P<'!!0'/BXPDF````(V,"J'K
MV6Z)PD0QXD0QPD'!R`(!T8GZ18G%P<(%`=&+E"2<````C900H>O9;D2)X$0Q
MP#'X`<*)R,'/`L'`!4$A_0'"1(G`"?@AR,')`D0)Z$2+K"2@````1XVD+-R\
M&X]!B?U$`>!!B=1!(<U!P<0%1`'@08G\00G,02'4P<H"10GL1(NL)*0```!'
MC80HW+P;CT&)S44!X$&)Q$$AU4'!Q`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPD
MJ````$*-O"_<O!N/08G51`'G18G$02'%0<'$!40!YT&)U$$)Q$4AQ$4)[$2+
MK"2L````0HV,*=R\&X]!B<5$`>%!B?Q!P<@"0<'$!44AQ40!X4&)Q$4)Q$$A
M_,'/`D4)[$2+K"2P````0HV4*MR\&X]%B<5$`>)!B<Q!(?U!P<0%1`'B18G$
M00G\02',P<D"10GL1(NL)+0```!"C80HW+P;CT&)_40!X$&)U$$AS4'!Q`5$
M`>!!B?Q!"<Q!(=3!R@)%">Q$BZPDN````$>-A"C<O!N/08G-10'@08G$02'5
M0<'$!44!X$&)S$$)U$$AQ$4)[$2+K"2\````0HV\+]R\&X]!B=5$`>=%B<3!
MR`)!P<0%02'%1`'G08G400G$12'$0<'(`D4)[$2+K"3`````0HV,*=R\&X]!
MB<5$`>%!B?Q%(<5!P<0%1`'A08G$10G$02'\P<\"10GL1(NL),0```!"C90J
MW+P;CT6)Q40!XD&)S$$A_4'!Q`5$`>)%B<1!"?Q!(<S!R0)%">Q$BZPDR```
M`$*-A"C<O!N/08G]1`'@08G402'-0<'$!40!X$&)_$$)S$$AU$4)[$2+K"3,
M````1XV$*-R\&X]!B<U%`>!!B<3!R@)!P<0%02'510'@08G,00G402'$P<@"
M10GL1(NL)-````!"C;POW+P;CT&)U40!YT6)Q$$AQ4'!Q`5$`>=!B=1!"<1%
M(<1!P<@"10GL1(NL)-0```!"C8PIW+P;CT&)Q40!X4&)_$4AQ4'!Q`5$`>%!
MB<1%"<1!(?S!SP)%">Q$BZPDV````$*-E"K<O!N/18G%1`'B08G,02']0<'$
M!40!XD6)Q$$)_$$AS$4)[$2+K"3<````0HV$*-R\&X]!B?U$`>!!B=3!R0)!
MP<0%02'-1`'@08G\00G,02'4P<H"10GL1(NL).````!'C80HW+P;CT&)S44!
MX$&)Q$$AU4'!Q`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDY````$*-O"_<O!N/
M08G51`'G18G$02'%0<'$!40!YT&)U$$)Q$4AQ$'!R`)%">Q$BZPDZ````$*-
MC"G<O!N/08G%00',B?E%(<7!P05!`<R)P40)P2'Y1`GI1(NL).P```!"C90J
MW+P;CP'*1(GAP<\"P<$%08G]`<J+C"3P````C;P(UL%BRD2)P$0QZ$0QX$'!
MS`(!QXG0P<`%`<>+A"3T````08V,`-;!8LI$B>A$,>`QT`'!B?C!P`4!P8G0
MBY0D^````,'(`D6-K!76P6+*1(GB08G`,<(Q^L'/`D$!U8G*03'XP<(%03'(
MP<D"00'5BY0D_````$&-E!36P6+*1(ND)`0!``!$`<)%B>A!P<`%1`'"1(N$
M)``!``!&C80`UL%BRHGX0HV\)];!8LI!B<PQR$0QZ$$!P(G0P<`%00'`1(GH
MP<@"03'$03'4P<H"1`'G18G$0<'$!40!YT2+I"0(`0``0HV,(=;!8LI!B<1!
M,=1%,<1!P<@"1`'A08G\0<'$!40!X42+I"0,`0``0HV$(-;!8LI!B=1%,<1!
M,?S!SP)$`>!!B<Q!P<0%1`'@1(ND)!`!``!"C90BUL%BRD6)Q$$Q_$$QS,')
M`D0!XD&)Q$'!Q`5$`>)$BZ0D%`$``$>-A"#6P6+*08G\03',03'$P<@"10'@
M08G40<'$!44!X$2+I"08`0``0HV\)];!8LI!B<Q!,<1!,=3!R@)$`>=%B<1!
MP<0%1`'G1(ND)!P!``!"C8PAUL%BRD&)Q$$QU$4QQ$'!R`)$`>%!B?Q!P<0%
M1`'A1(ND)"`!``!"C80@UL%BRD&)U$4QQ$$Q_,'/`D0!X$&)S$'!Q`5$`>!$
MBZ0D)`$``$*-E"+6P6+*18G$03'\03',P<D"1`'B08G$0<'$!40!XD2+I"0H
M`0``1XV$(-;!8LI!B?Q!,<Q!,<3!R`)%`>!!B=1!P<0%10'@1(ND)"P!``!&
MC:0GUL%BRHG/,<<QUT$!_$2)Q\'*`L''!4$!_(N\)#`!``"-O#G6P6+*B<$Q
MT40QP4'!R`(!ST2)X<'!!0'/BXPD-`$``(V$"-;!8LJ)T40QP40QX0'(B?G!
MP04!R$2)X42+I"0X`0``P<D"1HVD(M;!8LI$B<(QRC'ZP<\"00'4B<)!`?G!
MP@5G1(E.#$$!U(N4)#P!``!%`>.-E!76P6+*9T2)7@1$`<)!B<A!,?A!,<#!
MR`)$`<)%B>!$`=!!P<`%9XE&"$0!P@'+9XD69XE>$(N$)$P!``!D*P0E&```
M`'4-@<18`0``6UU!7$%=P^CL[/__9F8N#Q^$``````"005=!5D%505154X/L
M"$B%_P^$N@```(L%](H``&=$BRA%A>T/A*<```!G#[8'28G_28GTA,!T!#P]
M=4U%,?9G08M=`(7;="U$B>UF#Q]$``")WT2)\DR)_NB3Z___A<!U"&="@#PS
M/70_9XM=!(/%!(7;==R#Q`B)V%M=05Q!74%>05_##Q]``$&)_F=!#[9&`4&#
MQ@&$P'0$/#UU[D4I_NN<9@\?1```1"GM0HU<,P'!_0*)V&=!B2PD@\0(6UU!
M7$%=05Y!7\,/'X0``````(/$"#';B=A;74%<05U!7D%?PV9F+@\?A```````
M#Q\`059!54%455.![*````!DBP0E&````(F$))P````QP$B%_W0)9X`_`$B)
M_74KBX0DG````&0K!"48````#X4=`0``@<2@````6UU!7$%=05[##Q^`````
M`.A#ZO__08G$A<!TR42-+?DI``!,B>?H3>K__X7`#X2E````9X!X$RZ-6!-U
M"V>`>P$`=-\/'T``9X!X$RX/A)T```!(B>_HC>S__TB)WT&)QNB"[/__08U\
M!@+H..W__T2)Z4F)V4F)Z$F)QDB)Q[K_____O@$````QP.B8[/__3(GWB>;H
M/NO__TR)]X/X_W00BT0D&"4`\```/0!```!T7NC1[/__3(GWZ`GJ__],B>?H
ML>G__X7`#X5D____9@\?A```````3(GGZ/CI__](B>_H,.S__^GX_O__#Q\`
M9X![`2X/A5C___]G@'L"``^$'?___^E(____#Q]$``#HH_[__^N@Z(SJ__]F
M9BX/'X0``````)!52(G]@>R@````9(L$)1@```")A"2<````,<")YNCNZ___
MA<!U.HM4)!B!X@#P``"!^@!```!T"('Z`*```'4BO@(```!(B>_H<^G__X7`
M#Y3`#[;`ZPMF#Q^$```````QP(N4))P```!D*Q0E&````'4(@<2@````7</H
M`.K__T%6NO\/``!!54F)]4%454B)_8T]8B@``('L&!```&2+!"48````B80D
M#!```#'`B>9)B?3H!^S__X7`?DMG@'P$_P!$C7#_=7]%A?9T.D2)\KXO````
M3(GGZ,+J__](A<!T)62+!"4`````2`,%KH<``$2)\4R)XDB)[F>+..A-ZO__
MZR`/'P!DBP0E`````$@#!8F'``!,B>I(B>YGBSCH2^G__XN$)`P0``!D*P0E
M&````'47@<08$```74%<05U!7L,/'T``08G&ZX'H+NG__V9F+@\?A```````
M#Q\`05=!5D%505152(G]4TB)\X/L*&2+!"48````B40D'#'`9X`^/74#@\,!
M2(G?Z"[J__](B>^-="0808G$,<#H_?O__TB)QT&)Q87`#X0/`0``Z`KJ__]!
M.<0/AN$```"+1"081(L]YH8``(T,A0````!G#[9%`(3`#X2J`0``/#T/A*(!
M``")Z`\?A```````9P^V4`&#P`&$TG0%@/H]=>\IZ$*-?"`"08G-B4PD"&=%
M`R_H:.K__V=!B44`A<!T6&=!BP>+3"0(9XL4"&</MD4`C4T!9X@"A,!T(CP]
M=0SK'&8/'T0``(3`=!*#P0&#P@%G#[9!_V>(`CP]=>IGQ@(],<`/'T``9P^V
M#!AGB$P"`8/``83)=>^+1"0<9"L$)1@````/A1$!``"#Q"A;74%<05U!7D%?
MPP\?@``````QP&8/'T0``&</MA089T&(5`4`@\`!A-)U[NN]#Q]``$2+/>F%
M``!G18LW9T&+#H7)#X2X````13'M9@\?1```1(GH08/%`6=#BQ2NA=)U\(TT
MA0P```"+!1.8``"%P'5?QP4%F````0```(GWZ&[I__^)1"0,2(G'A<`/A%C_
M__]"C0RM`````$2)]HG*B4PD".BYYO__1(M$)`R+3"0(9T&)!V=#QT2H!```
M``!$B6PD&.EY_O__#Q^$``````!$B??H^.;__V=!B0=!B<"%P`^$`O___T*-
M#*T`````Z\,/'X``````,<#I=/[__[X(````13'MZ5O____HW^;__V9F+@\?
MA```````#Q]``(/L"&2+!"4`````2`,%WH0``(L5X(0``(T-,F0``(TU-24`
M`&>+.(/$".G!Z/__D%-DBP0E`````$@#!;"$``!GBSB)P^BV____9XL[C0V2
M)@``6\?"P$]``$4QR4F)R(TU#R4``.G%YO__#Q]$``!!5%53@>P@(```9(L$
M)1@```")A"0<(```,<")Y42-I"00$```Z,;F__](B>^-#><D``!$C0VK)```
M08G`N@$0``"^`0```#'`Z)+G__](B>^Z`!```$R)YNA"Z/__,>V%P'@CC7@!
MB</H\N?__TB)QXG%A<!T$(G:3(GFZ%_F__]GQD0=``")Z(N4)!P@``!D*Q0E
M&````'4+@<0@(```6UU!7,/HMN7__V8/'T0``.E+____9F8N#Q^$``````!!
M5T%628GV055!5%5(B?V-/5,D``!3@>RX$```9(L$)1@```")A"2L$```,<"-
M="0,Z(KX__^^+P```$B)[XG#Z#OF__](A<!T/DB)[HT]'B0``#'`Z";\__^)
MZ(N4)*P0``!D*Q0E&`````^%;0$``('$N!```%M=05Q!74%>05_#9@\?1```
M2(GO1(TE[",``.A)YO__3(GF3(GW08G%Z!OE__]!B<>%P'2>08/%`6=!@#\`
M#X3'````#Q]$``!%B?Z%VW02B=],B?;H;^7__X7`#X2)````3(GWZ/_E__]G
M08!\!_\O=1AF#Q]$``"#Z`%G08!\!_\O9T'&!`<`=.Y$`>@]_P\```^/.O__
M_XT-4"0``+H`$```18GX,<!$C;0DH````(/L"+X!````542-#4@C``!,B??H
MX.7__XUT)"!,B??HA.3__UI9A<!U$(M$)"@E`/```#T`@```=$Y,B>8Q_^A4
MY/__08G'A<`/A-/^__]G08`_``^%/O___X7;=`9G@#LN=!1$C3W3(@``N`$`
M``#I9?___P\?`&>`>P$`=+OKXP\?@`````"^`0```$R)]^@CX___A<!UH4R)
M]HT]IR(``.BQ^O__3(GWZ-GD__^)Q>E\_O__Z+WC__]F9BX/'X0``````&:0
M9P^V#X3)=!F)^F8/'T0``(/"`8#Y+V</M@H/1/J$R77OB?C#9F8N#Q^$````
M``"02(7_#X3'````54B)_5.#[`AG@#\`#X2%````Z*#D__^-5"C_.>IW$^F#
M````#Q\`@^H!.>H/A'T```!G@#HO=.\YZG9K#Q\`@^H!.>IT:6>`.B]U\SGJ
M=0WK10\?1```9X`Z+W4'@^H!.>IW\RGJ,<"-2@*!^0`0``!W&XT]CH,``(/"
M`;D`$```2(GN2(G[Z)OC__^)V(/$"%M=PP\?`(/$"(T]G2$``%M=Z>#C__\Y
MZG6R#Q]``&>`.B]TXH/$"(T]F2$``%M=Z<+C__]FD(T]<"$``.FUX___#Q]$
M``!!5T%6055!5%6-+7,A``!3@^Q89@]O!15@``!DBP0E&````(E$)$PQP(U<
M)!PQP`\I1"0@9@]O!01@``!FB40D0(E<)`P/*40D,&8/'T0``#'`2(G>2(GO
MZ&/U__](A<!T+HL%:(```(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?`&>+4`B#
MP`1GB1"%TG7RZ\"+7"0,C2WQ(```9@\?1```,<!(B=Y(B>_H$_7__TB%P'0N
MBP48@```BU0D'&>+`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72=?+K
MP(M<)`R-+:D@``!F#Q]$```QP$B)WDB)[^C#]/__2(7`="Z+!<A_``"+5"0<
M9XL`C0209XM0!&>)$(72=-,/'P!GBU`(@\`$9XD0A=)U\NO`BUPD#(TM8B``
M`&8/'T0``#'`2(G>2(GOZ'/T__](A<!T+HL%>'\``(M4)!QGBP"-!)!GBU`$
M9XD0A=)TTP\?`&>+4`B#P`1GB1"%TG7RZ\"+7"0,C2T9(```9@\?1```,<!(
MB=Y(B>_H(_3__TB%P'0NBP4H?P``BU0D'&>+`(T$D&>+4`1GB1"%TG33#Q\`
M9XM0"(/`!&>)$(72=?+KP(M<)`Q$C278'P``#Q]$```QP$B)WDR)Y^C3\___
M2(7`="Z+!=A^``"+5"0<9XL`C0209XM0!&>)$(72=-,/'P!GBU`(@\`$9XD0
MA=)U\NO`BUPD#$2-)3T?```/'T0``#'`2(G>3(GGZ(/S__](A<!T+HL%B'X`
M`(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?`&>+4`B#P`1GB1"%TG7RZ\"+7"0,
M1(TU1!\```\?1```,<!(B=Y,B??H,_/__TB%P'0NBP4X?@``BU0D'&>+`(T$
MD&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72=?+KP(M<)`Q$C2W^'@``#Q]$
M```QP$B)WDR)[^CC\O__2(7`="Z+!>A]``"+5"0<9XL`C0209XM0!&>)$(72
M=-,/'P!GBU`(@\`$9XD0A=)U\NO`BUPD#$2-/;@>```/'T0``#'`2(G>3(G_
MZ)/R__](A<!T+HL%F'T``(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?`&>+4`B#
MP`1GB1"%TG7RZ\!$BWPD#(T=!AX```\?1```,<!,B?Y(B=_H0_+__TB%P'0N
MBP5(?0``BU0D'&>+`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72=?+K
MP$R)_HT])!X``.@"\O__2(G&A<!T"DR)[S'`Z+'U__^+="0,C3T5'@``,<#H
MX/'__TB)QH7`=`V-/1,>```QP.B,]?__1(ML)`R-/0P>```QP$R)[NBW\?__
M2(G&A<!T-DR)YS'`Z&;U__\QP(TU%1X``$B)[^A6]?__BT0D3&0K!"48````
M=5&#Q%A;74%<05U!7D%?PTR)[HT]S!T``#'`Z&KQ__](B<:%P'0,3(GW,<#H
M&?7__^NQ2+A005)?0TQ%04@Y1"0Q=:!F@7PD.4X]=9>-="0[Z]3H$M[__V:0
M@^P89(L$)1@```")1"0,BP53?@``@_C_=!:+5"0,9"L4)1@```!U/8/$&,,/
M'T``C70D"(T]]1P``#'`Z._P__](B<(QP(72=!-G#[8"/#`/E<*$P`^5P`^V
MP"'0B04%?@``Z[7HIMW__V8/'T0``(/L".@8W?__B<?HX=W__XG"A<!T`V>+
M$(G0@\0(PV:0055!5$2-)8H=``!52(G]3(GG4X/L&&2+!"48````B40D##'`
MC70D".AS\/__A<!T!F>`.`!U*8M$)`QD*P0E&`````^%IP```$B)[H/$&$R)
MYS'`6UU!7$%=Z0'T__^02(GN2(G'2(G#Z/+;__](A<!T'8M$)`QD*P0E&```
M`'5O@\086UU!7$%=PP\?1```2(GOZ"C>__](B=]!B<7H'=[__T&-?`4"Z-/>
M__^#[`BZ_____TF)Z%-(B<=)B<5$C0V8&P``C0UZ'```O@$````QP.@HWO__
M6%J+1"0,9"L$)1@```!U"$R)[NE<____Z(O<__]F9BX/'X0``````$%7059!
M54F)_4%455.!['B!``!DBP0E&````(F$)&R!``"-!?T;``"-="1$QT0D4```
M``#'1"1T`````$F)],=$)%P`````B40D2(T%]1H``(E$)$R-!7X;``")1"1D
MC07%&P``B40D:(T%AQL``(E$)&R-!;D;``")1"1PC066&P``B40D5(T%J1L`
M`(E$)%B-!;$:``!(B40D($B)QS'`Z/KN__^%P'0*9X`X``^%G`0``#'`Z"7^
M__^)Q87`#X3K`P``B>_H]-S__XU\``'HJ]W__V=$#[9%`$&)QD6$P'0Z18GW
MC1U3&P``#Q]``$2)_T4/ML!(B=FZ_____[X!````,<"#Q0%!@\<"Z.[<__]G
M1`^V10!%A,!UTT2-?"1@C06X&@``1(GCZQ0/'P!G08M'!$&#QP2%P`^$1P$`
M`(G'2(G>,<#H4^[__TB)Q87`=-QG@#@`=-9(B<?HGO#__X7`=,I(B>_H(MS_
M_T&)P(7`#X0/`0``#Q^``````$2)PTB)W^@UW/__1(GR2(G72(E4)`B)Q>@C
MW/__1(V\!00$``"-+;49``!$B?_HS=S__TF)V$F)Z;X!````2(M4)`A(B00D
M2(G'08G&C05Z&@``C0UK&@``2(G[4KK_____4#'`Z!;<__^^P`$``$B)W^AY
MV___05A!68/X_W43Z$O:__]G1(L(08/Y$0^%"0,``$B+/"2-M"2`````B70D
M+.CIV___B<.%P`^$KP```(L%B7@``&=!BTT`O@$```"-%;D:``!,BP0D13'D
M9XLX,<#HZ-O__XN$)&R!``!D*P0E&`````^%.`@``('$>($``$R)X%M=05Q!
M74%>05_##Q^``````(U<)$B-!9,9``#K%0\?0`!GBT,$A<!T.(/#!&>`.`!T
M+XG%2(GOZ$WO__^%P'3A2(GOZ-':__]!B<"%P`^%MO[__V>+0P2%P'7.9@\?
M1```13'`Z:#^__^+A"28````)0#P```]`$````^%.O___XN$))P```")1"0(
MZ/G8__\Y1"0(#X4@____BX0DF````"7_`0``/<`!```/A0G___]$B?_H4-O_
M_XT]'!D``$2)YDB)1"08B40D,#'`Z%?L__](B<>%P`^$/`(``.@WVO__9T&+
M?0!(B<;H>O/__T&)Q(7`#X0?`@``1(GGZ$?:__]!B<>#^`-V+T&-?`3\C37+
M&```Z(_9__^%P'4;08/_!`^$Q@4``&=#@'P\^R\/A+D%```/'T``,<#HN?K_
M_X7`=19$B><Q]NA+V/__B40D*(7`#X7)`0``C35`&```C3W"%P``,<#H?.__
M_T2-+:H8``!$C3V,&```Z!G9__]!5;K_____28GI4$R+1"00C0UC&```,<!(
MBWPD*+X!````Z.+9__]86D2+9"0PZT-F#Q^$``````#H&]C__V>#.!%U0>C0
MV/__@\,!@^P(1(GY055)B>E%B?"Z_____U.^`0```$R)YU`QP.B9V?__@\0@
MOL`!``!,B>?H^=C__X/X_W2T2(L\).@;U___2(M<)!A(BWPD(#'`2(G>Z,?N
M__](B=_H7_K__^FR_?__9BX/'X0``````$2-="14C05>%P``1(GCZPUG08M&
M!(7`=#5!@\8$B<=(B=XQP.C'ZO__2(G'A<!TX&>`.`!TVNBEV/__B<6%P`^%
MT/O__V=!BT8$A<!UR[\-````C2T5%P``Z'+9__]!N%,```!!B<;IQ_O__XL%
MGG4``&=!BTT`O@$```"-%8X7``!,BP0D13'D9XLX,<#H_=C__^D0_?__#Q^$
M``````!(B<=(B<7HI?G__XN$)&R!``!D*P0E&`````^%-04``('$>($``$B)
M[UM=05Q!74%>05_I"-C__P\?A```````9T6+90#IU_W__[H"````2,?&[O__
M_T&)QHG'Z.#8__^-G"1@`0``N@8```!$B?=(B=Z)7"04Z%78__^`O"1@`0``
M`'4.@+PD80$``$,/A#L$``"+?"0H,=(Q]D4Q_^B=V/__2(EL)#A(N`$C16>)
MJ\WO2(F$)(````!(N/[<NIAV5#(02(F$)(@```"X\.'2PTB)A"20````C80D
MG````,>$))@`````````QX0DW`````````#'1"0(`````(E$)#1F#Q]$``!$
MBVPD%(M\)"BZ`(```$R)[NBRU___B<.%P`^.*`$``#'2C03=``````-$)`B+
M;"04#Y+"B40D"(/Z`8F$))0```")V(N4)-P```!!@]__P>@=00''1(F\))@`
M``"%T@^%DP```(/[/P^.V0(``(/K0$2+;"0L08G>0<'N!D6-9@%!P>0&00'L
M9_,/;TT`9_,/;U403(GO@\5`9_,/;UW@9_,/;V7P#Q&,))P````/$90DK```
M``\1G"2\````#Q&D),P```#HK=K__T0YY76X0<'F!D0I\XM\)#1$B>:Y1```
M`(G:Z/[5__^)G"3<````Z0K___]FD+A`````3(GN*=`YV`]/PXG%BT0D-(T\
M$(GJZ)'5__^+A"3<`````>B)A"3<````@_A`#X2V`0``BX0DE````$2+O"28
M````B40D".FX_O__BWPD*$B+;"0XZ"+4__^+1"0(P>@#@^`_9\:$!)P```"`
MC4@!BT0D-`'(@_DX#X[4`0``OD`````ISG0.,=)GQ@00`(/"`3GR<O2+?"0L
MZ-W9__]F#^_`2,>$),P`````````#Q&$))P````/$80DK`````\1A"2\````
MBT0D"(M\)"Q!#\]$B;PDU````$2-K"0P`0``1(V\)!$!```/R$6)[HF$)-@`
M``!$C:0D6`$``.AYV?__BX0D@`````^WE"2`````C1W3$P``B<'!Z!"(A"01
M`0``9L'"",'I&(N$)(0```!FB90D$@$``$&)R`_(B80D%`$``(N$)(@````/
MR(F$)!@!``"+A"2,````#\B)A"0<`0``BX0DD`````_(B80D(`$``.L-#Q]`
M`&=%#[8'08/'`42)]T4/ML!(B=FZ_____[X!````,<!!@\8"Z`C5__]%.?1U
MT\:$)%@!````C06*$P``4$%53(M$)!"^`0```$F)Z3'`2(M\)"B-#3D3``"Z
M_____^C.U/__65Y$BV0D,.D^^___BWPD+"GK`VPD%.B#V/__BX0DE````$2+
MO"28````B40D".E8_?__9T6+;01%A>T/A#WZ__]$B>_H1=3__X/X`P^&+/K_
M_T&-?`7\C37-$@``Z(S3__^%P$4/1.7I$?K__T&)[.F(_?__NC@````Q]BG*
M@_H(<ROVP@0/A=(```"%T@^$5?[__V?&``#VP@(/A$C^__\Q_V=FB7P0_ND[
M_O__C4@(9TC'``````!G2,=$$/@`````@^'X*<@!PH/B^(/Z"`^"$_[__X/B
M^#'`9TB)-`&#P`@YT'+TZ?W]__^`O"1B`0``00^%M_O__X"\)&,!``!##X6I
M^___@+PD9`$``$@/A9O[__^`O"1E`0``10^%C?O__T2+="0HN@(```!(Q\;&
M____1(GWZ"'4__^Z*0```$B)WD2)]^BAT___C040$@``4%/I@O[__P\?0`!G
MQP``````9\=$$/P`````Z7;]___HUM'__V8/'T0``$%505154X/L&&2+!"48
M````B40D##'`9(L$)0````!(`P7*;P``C70D"(T]HQ```$F)]&>+&&</MD-D
M9XA#93'`Z*KD__^%P'0*9X`X,0^$O`(``#'`Z-7N__]DBP0E`````$@#!89O
M``!GBQB)W[D+````N@$```"--6`1``#H#-'__X7`#X3%````9XM`#(,]T8$`
M``%GBV@8#XZP````,=OK3@\?`"4`02``/0!!``!T?V=!BWT`N0(````QTNA;
MT___B<:+!9>!``!$C6L!9XM\F`3HE='__T&)P(L%A($``$6%P'5=@\,".=A$
MB>M^4V2+!"4`````2`,%[FX``#')B=I(B>YGBSA!B<7HO-'__X7`="AGBS!G
MBT8(B<*!X@`$(`"!^@`$```/A77___]GBW8,ZXX/'X``````BP4B@0``C5#_
M.=H/A$\!``!DBP0E`````$@#!9!N``"Y`P```+H!````C35T$```9XLXB</H
M%M#__XG%A<!T)V>+0`QGBSN-%5D0``!GBS#H*]#__V>+10QGBP!G]D`*0`^%
MDP$``&2+!"4`````2`,%.FX``+D#````N@$```"--240``!GBSB)P^C`S___
MB<6%P'0J1(GFC3W"#@``,<#H"N/__TB)PH7`#X0O`0``9XM%#&>+.V>+,.C`
MS___9(L$)0````!(`P7A;0``N@$```"--=,/``!GBSB)P^B<SO__9XL[C175
M#P``2(G&Z(O/__]GBP-$B>:-/5<.``!GQD!E`#'`Z*/B__^)!1F```")PH7`
M#X2#````08G4OL`!``!,B>?H4]#__XU0`8/Z`78)@_@1#X70````BT0D#&0K
M!"48````#X6Y````@\086UU!7$%=PV8/'T0``(/X`0^.J/[__[L!````9I!D
MBP0E`````$@#!3%M``!(B>Z#PP%GBSCHL\[__SD=E7\``'_;Z7?^__]F#Q]$
M``"+/7Y_``#H9?+__XD%>W\``(G"A<`/A6+___^-/:</``#HFM#__V8N#Q^$
M``````!G@'@!``^$4OW__^DT_?__BP4^?P``9XLP9XM%#&>+..B;Y/__Z<;^
M__]GBSN)QNCLS___Z5[^___H@L[__XL5$'\``(G!C3UT#P``,<!GBS),B>+H
M-]#__P\?@`````!!5%5(B?V#[`CHTNK__TB)Q^B:ZO__28G$,<#H,/#__X7`
M="-(A>UT'F>`?0``=!>Z!````(TU\@T``$R)Y^@MS?__A<!T"8/$"%U!7,-F
MD(/$"$B)[UU!7.D2XO__9I#S#Q[ZBPU*;@``Z:'/__\`\P\>^DB#[`A(@\0(
MPP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#4`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$;
M`SO0````&0```."`__\4`0``L(3__S0&``"PAO__[````."&__\``0``H(?_
M_S@!``!PE?__>`$``&"6___P`0``T)?__S0"``!0F/__6`(``#"9__^4`@``
M@)O__^`"``"PF___^`(``/";__\4`P``H)S__T@#``"PG/__7`,``*">__^\
M`P``T)[__]`#``"PG___%`0``$"D__]D!```L*3__X`$``#0I/__F`0``-"E
M___P!```@+#__\0%``#PL___``8``%"T__]@!@``%``````````!>E(``7@0
M`1L,!PB0`0``$````!P```"\A?__*`````!$!Q`0````,````-B%__\%````
M`````"````!$````Q'___]`#````#A!&#AA*#PMW"(``/QH[*C,D(CP```!H
M````8(;__\0-````0@X0C0)%#AB,`T$.((8$00XH@P5&#H`#`ZD-"@XH00X@
M00X80@X00@X(00L```!T````J````/"3___B`````$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T,.0`)J"@XX0PXP00XH0@X@0@X80@X00@X(10MU
M"@XX00XP00XH0@X@0@X80@X00@X(20M##CA%#C!!#BA"#B!"#AA"#A!"#@A`
M````(`$``&B4__]D`0```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P9&#M`!
M>@H.,$$.*$$.($(.&$(.$$(."$@+`"````!D`0``E)7__X``````00X0A@))
M#K`!`F\*#A!!#@A!"S@```"(`0``\)7__](`````0@X0C@)'#AB-`T4.((P$
M00XHA@5/#L`@`IX*#BA!#B!"#AA"#A!"#@A%"T@```#$`0``E);__T$"````
M0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1@Y@`QL!"@XX00XP00XH
M0@X@0@X80@X00@X(2`L4````$`(``)B8__\O`````$,.$&<."``8````*`(`
M`+"8__\[`````$$.$(,"8PX(````,````$0"``#4F/__J@````!"#A",`D$.
M&(8#00X@@P1&#L!``I8*#B!!#AA!#A!"#@A!"Q````!X`@``4)G__P4`````
M````7````(P"``!,F?__XP$```!"#A"/`D(.&(X#10X@C01"#BB,!4$.,(8&
M2@XX@P=&#O`A`EL*#CA!#C!!#BA"#B!"#AA"#A!"#@A'"P*C#O@A1@Z`(EP.
M^"%!#O`A````$````.P"``#<FO__)`````````!```````,``/B:___;````
M`$H.$(8"1`X8@P-##B`"B0H.&$$.$$$."$0+0PH.&$?##A!!Q@X(10M1#AA'
MPPX00<8."$P```!$`P``E)O__XX$````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D<..(,'0PZ0`0,H!`H..$$.,$$.*$(.($(.&$(.$$(."$$+````&```
M`)0#``#4G___:@````!##B!H"@X(10L``!0```"P`P``**#__QX`````0PX0
M6@X(`%0```#(`P``,*#___4`````0@X0C0)"#AB,`T@.((8$1PXH@P5##D!Y
M"@XH1@X@00X80@X00@X(1@MD"@XH00X@00X80@X00@X(1@M@#DA)#E!@#DA!
M#D#0````(`0``-B@__^J"@```$(.$(\"0@X8C@-"#B"-!$4.*(P%00XPA@9!
M#CB#!T8.L(,"`\H!#KB#`D8.P(,"5@ZX@P)"#K"#`@)X"@XX1`XP00XH0@X@
M0@X80@X00@X(2`L#<0$.N(,"20[`@P)=#KB#`D$.L(,"9@ZX@P)%#L"#`DP.
MR(,"20[0@P)*#K"#`@,,`0H..$0.,$$.*$(.($(.&$(.$$(."$T+`WP##KB#
M`D(.P(,"90ZX@P)!#K"#`@-2`0H.N(,"00[`@P))"P```#@```#T!```M*K_
M_VD#````0@X0C0)"#AB,`T$.((8$00XH@P5##D`#B@(*#BA!#B!!#AA"#A!"
M#@A'"S`````P!0``Z*W__UX`````0@X0C`)!#AB&`T8.(`)!"@X800X00@X(
M0PM##AA$#A!"#@@H````9`4``'1^____`0```$(.$(P"00X8A@-##D`#80$*
M#AA$#A!"#@A!"Q````"0!0``Z*W__P\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````T"9``*`F0``!````*P,```$````]
M`P```0```$<#```!````40,```$```!C`P``#P```)P$```,`````"!```T`
M``"@4T``&0```'B^0``;````!````!H```!\OD``'`````0```#U_O]O2`)`
M``4```#T"$``!@````0#0``*````WP0```L````0````%0`````````#````
MZ+]```(```#0`@``%`````<````7````>`]```<```#T#D``"````(0````)
M````#````/[__V^4#D``____;P(```#P__]OU`U`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"`OD``````````````
M```````````````V($```````$8@0```````5B!```````!F($```````'8@
M0```````AB!```````"6($```````*8@0```````MB!```````#&($``````
M`-8@0```````YB!```````#V($````````8A0```````%B%````````F(4``
M`````#8A0```````1B%```````!6(4```````&8A0```````=B%```````"&
M(4```````)8A0```````IB%```````"V(4```````,8A0```````UB%`````
M``#F(4```````/8A0```````!B)````````6(D```````"8B0```````-B)`
M``````!&(D```````%8B0```````9B)```````!V(D```````(8B0```````
MEB)```````"F(D```````+8B0```````QB)```````#6(D```````.8B0```
M````]B)````````&(T```````!8C0```````)B-````````V(T```````$8C
M0```````5B-```````!F(T```````'8C0```````AB-```````"6(T``````
M`*8C0```````MB-```````#&(T```````-8C0```````YB-`````````````
M`````/_____88D``1T-#.B`H4$Q$+4QI;G5X*2`Q,2XS+C`@,C`R,C`T,C$@
M*')E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M
M:60`+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+D%"22UT86<`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N
M=```````````````````````````````````````````````````````````
M"P````$````"````M`%``+0!```:```````````````!`````````!,````'
M`````@```-`!0`#0`0``)```````````````!``````````F````!P````(`
M``#T`4``]`$``#0```````````````0`````````.0````<````"````*`)`
M`"@"```@```````````````$`````````$<```#V__]O`@```$@"0`!(`@``
MO`````8`````````!`````0```!1````"P````(````$`T``!`,``/`%```'
M`````0````0````0````60````,````"````]`A``/0(``#?!```````````
M```!`````````&$```#___]O`@```-0-0`#4#0``O@````8``````````@``
M``(```!N````_O__;P(```"4#D``E`X``&`````'`````@````0`````````
M?0````0````"````]`Y``/0.``"$````!@`````````$````#````(<````$
M````0@```'@/0`!X#P``T`(```8````7````!`````P```"1`````0````8`
M````($```"```!L```````````````0`````````C`````$````&````("!`
M`"`@``#0`P`````````````0````$````)<````!````!@```/`C0`#P(P``
MKR\`````````````$`````````"=`````0````8```"@4T``H%,```T`````
M``````````0`````````HP````$````"`````&!```!@``!`/P``````````
M```0`````````*L````!`````@```$"?0`!`GP``U```````````````!```
M``````"Y`````0````(````4H$``%*```*0%``````````````0`````````
MPP````X````#````>+Y``'BN```$```````````````$````!````,\````/
M`````P```'R^0`!\K@``!```````````````!`````0```#;````!@````,`
M``"`OD``@*X``!`!```'``````````0````(````Y`````$````#````D+]`
M`)"O``!8```````````````(````"````.D````!`````P```.B_0`#HKP``
M^`$`````````````"`````@```#R`````0````,```#@P4``X+$``!``````
M``````````0`````````^`````@````#`````,)``/"Q```T$```````````
M```@`````````/T````!````,`````````#PL0``*P```````````````0``
M``$````!`````P``````````````&[(```8!``````````````$`````````
